@@ -35,7 +35,7 @@
 #'   We advise using this option only for locally, multiple objective and robust optimal designs.
 #'
 #'
-#' What to follows shows  how \code{sym_point} and \code{sym} may be useful? \cr
+#' What follows shows  how \code{sym_point} and \code{sym} may be useful? \cr
 #'  Assume the 2PL model of the form \eqn{ P(Y=1) = \frac{1}{1+exp(-b(x - a))}}{P(Y=1) = 1/(1+exp(-b(x - a)))} and
 #'  let the parameters \eqn{a} and \eqn{b}
 #'   belong to
@@ -86,7 +86,7 @@ ICA.control <- function(ncount = 40, nimp = ncount/10, assim_coeff = 4, revol_ra
   ## if TRUE, then ld and ud does not have the lower bound and upper bound for the weights.
   ## In this case, the countries are only the points and not weights
   if (sym && is.null(sym_point))
-    stop("symetric point should be given by 'sym_point'")
+    stop("symmetric point should be given by 'sym_point'")
   if (equal_weight && sym)
     stop("symmetric property does not work when only equal-weighted design is requested")
   #############################################################*
@@ -102,7 +102,7 @@ ICA.control <- function(ncount = 40, nimp = ncount/10, assim_coeff = 4, revol_ra
   # if (functype[1] == "Bayesian")
   #   checkfreq <- Inf
   if (plot_sens && checkfreq == 0)
-    warnings("the sensitivity plot will not be plotted when 'checkfreq' in 'ICA.control' is zero.")
+     message("Note: the sensitivity plot will not be plotted when 'checkfreq' in 'ICA.control' is zero.")
   if (!all(plot_3d %in%  c("lattice", "rgl")))
     stop("'plot_3d' must be 'lattice' or 'rgl'")
   ############################################################*
@@ -120,7 +120,8 @@ ICA.control <- function(ncount = 40, nimp = ncount/10, assim_coeff = 4, revol_ra
   return(list(ncount = ncount, nimp = nimp, assim_coeff = assim_coeff, revol_rate = revol_rate, damp = damp,  uniting_threshold = uniting_threshold,
               equal_weight = equal_weight, sym = sym, sym_point = sym_point,
               stop_rule = stop_rule[1], stoptol = stoptol, checkfreq = checkfreq,
-              plot_cost = plot_cost, plot_sens = plot_sens, trace = trace, rseed = rseed))
+              plot_cost = plot_cost, plot_sens = plot_sens, trace = trace, rseed = rseed,
+              plot_3d = plot_3d))
 }
 ######################################################################################################*
 ######################################################################################################*
@@ -148,7 +149,7 @@ ICA.control <- function(ncount = 40, nimp = ncount/10, assim_coeff = 4, revol_ra
 #' @param x0 Vector of starting values for maximizing the sensitivity (derivative) function over the design space \eqn{x}.
 #' It will be passed to the optimization function \code{\link[nloptr]{nloptr}}.
 #' @param optslist A list. It will be passed to the argument \code{opts}  of the function \code{\link[nloptr]{nloptr}} to find the maximum of the sensitivity function over the design space. See 'Details'.
-#' @param ... Further arguments will be passed to \code{\link{nl.opts}} from package \code{\link[nloptr]{nloptr}}.
+#' @param ... Further arguments will be passed to \code{\link[nloptr:nl.opts]{nl.opts}}.
 #' @details
 #' ELB is a measure of  proximity of a design to the optimal design without knowing the latter.
 #' Given a design, let \eqn{\epsilon} be the global maximum
@@ -184,9 +185,11 @@ ICA.control <- function(ncount = 40, nimp = ncount/10, assim_coeff = 4, revol_ra
 #'   optimization algorithm to find the global maximum
 #'   of the sensitivity (derivative) function over the design space.
 #' @export
+#' @return A list containing \code{x0} (starting values or NULL) and \code{optslist} (control parameters for \code{\link[nloptr]{nloptr}}).
 #' @importFrom nloptr nl.opts
 #' @importFrom nloptr nloptr.print.options
 #' @examples
+#' 
 #' sens.control()
 #' sens.control(optslist = list(maxeval = 1000))
 sens.control <- function(x0 = NULL,
