@@ -922,7 +922,7 @@ check_common_args <- function(fimfunc, formula, predvars, parvars, family,
   if (!is.numeric(iter) || (iter %% 1) != 0 || iter <= 0)
     stop("\"iter\" must be a positive integer number")
   if (!is.null(prior)){
-    if (class(prior) != "cprior")
+     if (!inherits(prior, "cprior"))
       stop("'prior' must be a list of class 'cprior'. See ?normal")
     if (!is.list(prior))
       stop("'prior' must be a list")
