@@ -445,7 +445,7 @@ create_optim_func <- function(type, lp_nofixed, up_nofixed, crt.minimax.control,
                             fixedpar_id = fixedpar_id,
                             npred = npred)
 
-      counts <- out$count + out_nloptr$iterations
+      counts <- out$counts + out_nloptr$iterations
       #counts <- out$count + out_nloptr$iter
       minima <- out$minima
       minima_nloptr <- c(out_nloptr$solution, out_nloptr$objective)
@@ -677,8 +677,8 @@ create_criterion_minimax <- function(FIM, type, lp, up, localdes = NULL, npar, r
     crfunc <- switch(type, "minimax" = crfunc_minimax, "standardized" = crfunc_standardized, "locally" = crfunc_locally, "robust" = crfunc_ave)
   }
   if (crt_type == "user"){
-    if (type == "standarized" & crt_type == "user")
-      stop("'standardized' criterion is not defined for the user given criterion.")
+    if (type == "standardized" & crt_type == "user")
+      stop("'standaized' criterion is not defined for the user given criterion.")
     if (type == "minimax") {
       crfunc_minimax <- function(param, q, npred) {
         if (!is.only.w){
