@@ -34,12 +34,17 @@
 #'    integration over \Theta -log|M(\xi, \theta)|\pi(\theta) d\theta.}
 #'
 #' An object of class \code{cprior}  is a  list with the following components:
-#' \itemize{
-#'  \item{\code{fn}: }{Prior distribution as an R \code{function} with argument \code{param} that is the vector of the unknown parameters. See below.}
-#'  \item{\code{npar}: }{Number of unknown parameters and is equal to the length of \code{param}}.
-#'  \item{\code{lower}: }{Argument \code{lower}. It has the same length as \code{param}}.
-#'  \item{\code{upper}: }{Argument \code{upper}. It has the same length as \code{param}}.
+#' \describe{
+#'   \item{fn}{Prior distribution as an R \code{function} with argument \code{param}, 
+#'             which is the vector of the unknown parameters.}
+#'
+#'   \item{npar}{Number of unknown parameters (equal to the length of \code{param}).}
+#'
+#'   \item{lower}{Lower bounds. A numeric vector with the same length as \code{param}.}
+#'
+#'   \item{upper}{Upper bounds. A numeric vector with the same length as \code{param}.}
 #' }
+#' 
 #' A \code{cprior} object  will be passed to the argument \code{prior} of the function \code{\link{bayes}}.
 #'  The argument \code{param} in \code{fn} has the same order as the argument \code{parvars} when the model is specified by a \code{formula}.
 #' Otherwise, it is the same as the argument \code{param} in the function \code{fimfunc}.\cr
@@ -309,6 +314,7 @@ bayes <- function(formula,
 #'  although the process may take too long. The user should choose a set of less conservative values
 #'  via the argument \code{sens.bayes.control} when the CPU-time is too long or matters.
 #'@export
+#'@return An object of class \code{'sensminimax'}. See \code{\link{sensminimax}} for structure details.
 #'@example inst/examples/sensbayes_examples.R
 sensbayes <- function(formula,
                       predvars, parvars,
@@ -412,6 +418,7 @@ sensbayes <- function(formula,
 #' @references  McGree, J. M., Eccleston, J. A., and Duffull, S. B. (2008). Compound optimal design criteria for nonlinear models. Journal of Biopharmaceutical Statistics, 18(4), 646-661.
 #' @importFrom utils capture.output
 #' @export
+#' @return An object of class \code{'sensminimax'}. See \code{\link{sensminimax}} for structure details.
 #' @inherit bayes return
 #' @example inst/examples/bayescomp_examples.R
 #' @seealso \code{\link{sensbayescomp}}
@@ -751,8 +758,9 @@ sens.bayes.control <- function(method = c("cubature", "quadrature"),
 #'     returns a full grid (default).
 #'      \code{"sparse"} for combination technique,
 #'       leads to a regular sparse grid.}
-#'   \item{\code{level.trans}}{Logical variable denotes either to take the levels as number of grid points (FALSE = default) or to transform in that manner that number of grid points = 2^(levels-1) (TRUE). See, code{\link[mvQuad]{createNIGrid}}, for details.}
+#'   \item{\code{level.trans}}{Logical variable denotes either to take the levels as number of grid points (FALSE = default) or to transform in that manner that number of grid points = 2^(levels-1) (TRUE). See, \code{\link[mvQuad]{createNIGrid}}, for details.}
 #' }
+#' 
 #'  \code{quadrature} is activated when \code{crt.bayes.control$method = "quadrature"} in
 #'       any of the parent functions (for example, \code{\link{bayes}}).
 #'
@@ -808,8 +816,7 @@ crt.bayes.control <- function(method = c("cubature", "quadrature"),
 #' @param ... An argument of no further use.
 #' @seealso \code{\link{bayes}}
 #' @export
-
-
+#' @return Returns an updated object of class \code{'minimax'} with the same structure as the input, containing additional iterations of Bayesian algorithm. See \code{\link{bayes}} for the complete structure description.
 # @importFrom nloptr directL you have it in minimax
 #' @importFrom mvQuad createNIGrid
 #' @importFrom mvQuad rescale
@@ -1007,7 +1014,6 @@ bayes.update <- function(object, iter,...){ # 06212020@seongho
 
     if (!is.null(ICA.control$rseed)){
       do.call("RNGkind",as.list(arg$updating$oldRNGkind))  ## must be first!
-      assign(".Random.seed", arg$updating$oldseed , .GlobalEnv)
     }
   }
   ##########################################################################*
